@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.12345';
+our $VERSION = '0.123456';
 use 5.006;
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ use Time::HiRes qw(gettimeofday);
 use Terse::WebSocket;
 use Want qw/want/;
 use Digest::SHA;
+use Struct::WOP qw/all/ => { type => ['UTF-8'], destruct => 1 };
 
 our ($JSON, %PRIVATE);
 BEGIN {
@@ -212,7 +213,7 @@ sub serialize {
 	my ($self, $die) = @_;
 	my $pretty = !!(reftype $self eq 'HASH' && $self->{_pretty});
 	my $out = eval {
-		$JSON->pretty($pretty)->encode($self);
+		$JSON->pretty($pretty)->encode(maybe_decode($self));
 	};
 	die $@ if ($@ && $die);
 	return $out || $@;
@@ -381,7 +382,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.12345
+Version 0.123456
 
 =cut
 
